==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/MemoryEfficientRasUnion.h <==
// public class soot.jimple.toolkits.pointer.MemoryEfficientRasUnion

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e37da4b56460387d soot_jimple_toolkits_pointer_MemoryEfficientRasUnion
// @dep_class 9dbbb271543e0b8f soot_jimple_toolkits_pointer_Union

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_Union

#include "soot/jimple/toolkits/pointer/Union.h"

#ifndef _JC_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion_H_
#define _JC_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Set$object;
struct _jc_soot_PointsToSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$addAll$ee80ba7ccfb17ce5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *);
extern jboolean _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$hasNonEmptyIntersection$15a39246543071be(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$possibleTypes$bdfe38321205065e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$addAll$ee80ba7ccfb17ce5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$hasNonEmptyIntersection$15a39246543071be;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$possibleTypes$bdfe38321205065e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods {
	jboolean	(*addAll$ee80ba7ccfb17ce5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *);
	jboolean	(*hasNonEmptyIntersection$15a39246543071be)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *);
	struct _jc_object	*(*possibleTypes$bdfe38321205065e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_Union$vmethods	soot_jimple_toolkits_pointer_Union;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods	soot_jimple_toolkits_pointer_MemoryEfficientRasUnion;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs {
	struct _jc_java_util_HashSet$object	*subsets;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs {
    _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs	soot_jimple_toolkits_pointer_MemoryEfficientRasUnion;
    _jc_soot_jimple_toolkits_pointer_Union$sub_refs	soot_jimple_toolkits_pointer_Union;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs	soot_jimple_toolkits_pointer_Union;
    _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs	soot_jimple_toolkits_pointer_MemoryEfficientRasUnion;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object {
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_MemoryEfficientRasUnion, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/MemoryEfficientRasUnion.h <==
// public class soot.jimple.toolkits.pointer.MemoryEfficientRasUnion

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e37da4b56460387d soot_jimple_toolkits_pointer_MemoryEfficientRasUnion
// @dep_class 9dbbb271543e0b8f soot_jimple_toolkits_pointer_Union

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_Union

#include "soot/jimple/toolkits/pointer/Union.h"

#ifndef _JC_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion_H_
#define _JC_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Set$object;
struct _jc_soot_PointsToSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$addAll$ee80ba7ccfb17ce5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$hasNonEmptyIntersection$15a39246543071be(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method$possibleTypes$bdfe38321205065e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$addAll$ee80ba7ccfb17ce5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$hasNonEmptyIntersection$15a39246543071be;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$method_info$possibleTypes$bdfe38321205065e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods {
	jboolean	(*addAll$ee80ba7ccfb17ce5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNonEmptyIntersection$15a39246543071be)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*possibleTypes$bdfe38321205065e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_Union$vmethods	soot_jimple_toolkits_pointer_Union;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vmethods	soot_jimple_toolkits_pointer_MemoryEfficientRasUnion;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs {
	struct _jc_java_util_HashSet$object	*subsets;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs {
    _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_refs	soot_jimple_toolkits_pointer_MemoryEfficientRasUnion;
    _jc_soot_jimple_toolkits_pointer_Union$sub_refs	soot_jimple_toolkits_pointer_Union;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs	soot_jimple_toolkits_pointer_Union;
    _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$sub_nonrefs	soot_jimple_toolkits_pointer_MemoryEfficientRasUnion;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$object {
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$vtype _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_MemoryEfficientRasUnion, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_MemoryEfficientRasUnion_H_ */
